.. _pydl.goddard.astro:

============================================
Goddard astro package (`pydl.goddard.astro`)
============================================

Introduction
------------

This is a placeholder for Goddard astro package documentation.

.. automodapi:: pydl.goddard.astro
   :no-inheritance-diagram:
